@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Exporter);
 
-our $VERSION = '0.028';
+our $VERSION = '0.029';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Tickit::DSL - domain-specific language for Tickit terminal apps
 
 =head1 VERSION
 
-version 0.028
+version 0.029
 
 =head1 SYNOPSIS
 
@@ -114,8 +114,10 @@ use Tickit::Widget::Static;
 use Tickit::Widget::Statusbar;
 use Tickit::Widget::Tabbed;
 use Tickit::Widget::Table;
+use Tickit::Widget::Term;
 use Tickit::Widget::Tree;
 use Tickit::Widget::VBox 0.46; # the hypothesis is that this may help catch old Tickit installs
+use Tickit::Widget::VHBox;
 use Tickit::Widget::VSplit;
 
 use List::UtilsBy qw(extract_by);
@@ -139,7 +141,7 @@ our @EXPORT = our @EXPORT_OK = qw(
 	static entry checkbox button
 	radiogroup radiobutton
 	scroller scroller_text scroller_richtext scrollbox
-	console
+	console term
 	tabbed
 	tree table breadcrumb
 	placeholder placegrid decoration
@@ -709,6 +711,25 @@ sub console(&@) {
 	$w
 }
 
+=head2 term
+
+Terminal widget.
+
+ term command => '/bin/bash';
+
+=cut
+
+sub term(@) {
+	my %args = @_;
+	my %parent_args = map {; $_ => delete $args{'parent:' . $_} } map /^parent:(.*)/ ? $1 : (), keys %args;
+	my $w = Tickit::Widget::Term->new(
+		%args
+	);
+	local @WIDGET_ARGS = (@WIDGET_ARGS, %parent_args);
+	apply_widget($w);
+	$w
+}
+
 =head2 logpanel
 
 Displays any log messages raised by L<Log::Any> or, optionally, through STDERR.
@@ -1461,7 +1482,7 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
